@@ -1,3 +1,5 @@
 pub mod parse;
 pub mod read;
-pub mod write;
\ No newline at end of file
+pub mod write;
+#[cfg(test)]
+mod tests;
\ No newline at end of file
